@@ -46,6 +46,10 @@ def test_cloudtrail_get_events_raw_format(fetcher_event_raw):
     assert "EventName" not in event
 
 
+def test_cloudtrail_fetcher_is_s3_fetching_available(cloudtrail_fetcher):
+    assert cloudtrail_fetcher.is_s3_fetching_available
+
+
 def test_cloudtrail_get_events_boto3_format_matching(fetcher_event_boto3):
     event = fetcher_event_boto3
 
