@@ -1,4 +1,5 @@
 import json
+import decimal
 import logging
 from datetime import datetime
 from datetime import timedelta
@@ -19,6 +20,10 @@ def _convert_resources_node(resources: list[dict[str, str]]) -> list[dict[str, s
 
     return output
 
+def json_default(obj):
+    if isinstance(obj, decimal.Decimal):
+        return str(obj)
+    raise TypeError
 
 def convert_to_boto3(event):
     """
@@ -36,7 +41,7 @@ def convert_to_boto3(event):
     response["Resources"] = _convert_resources_node(event.get("resources", []))
     response["EventSource"] = event["eventSource"]
 
-    response["CloudTrailEvent"] = orjson.dumps(event).decode("UTF-8")
+    response["CloudTrailEvent"] = orjson.dumps(event, default=json_default).decode("UTF-8")
     identity = event["userIdentity"]
 
     if (
@@ -96,4 +101,4 @@ def day_chunks(start: datetime, end: datetime) -> Iterator[list[datetime]]:
                 - timedelta(microseconds=1)
             )
             yield [chunk_start, chunk_end]
-            current_date = chunk_end
+            current_date = chunk_end
\ No newline at end of file
